==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-volume/translations/volume_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>Verhoog volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>Verlaag volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>Demp/ontdemp geluid</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Volume: de volgende sneltoetsen kunnen niet worden geregistreerd: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>Volume: %1%%2</source>
        <translation>Volume: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>(muted)</source>
        <translation>(gedempt)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Instellingen Volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Te beheren apparaat</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Gedrag</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Demp bij middelklik</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Toon bij muisklik</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Sta volumes toe boven 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>Wijzigingen in volume altijd melden</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="91"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>Wijzigingen in volume vanaf toetsenbord altijd melden</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="106"/>
        <source>Volume adjust step</source>
        <translation>Stapgrootte voor volumeverandering</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="125"/>
        <source>External Mixer</source>
        <translation>Extern mengpaneel</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="55"/>
        <source>Launch mixer</source>
        <translation>Start mengpaneel</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="56"/>
        <source>Mi&amp;xer</source>
        <translation>&amp;Mengpaneel</translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-volume/translations/volume_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>Volume verhogen</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>Volume verlagen</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>Geluid dempen/ontdempen</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Volumeregeling: de volgende sneltoetsen kunnen niet worden vastgelegd: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>Volume: %1%%2</source>
        <translation>Volumeniveau: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>(muted)</source>
        <translation>(gedempt)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Volumeregeling-instellingen</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Te beheren apparaat</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Gedrag</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Dempen met middelste muisknop</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Tonen na muisklik</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Volumeniveaus boven 100% (0dB) toestaan</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>Melding tonen als volumeniveau wijzigt</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="91"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>Melding tonen als volumeniveau wijzigt via toetsenbord</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="106"/>
        <source>Volume adjust step</source>
        <translation>Stapgrootte bij volume-aanpassing</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="125"/>
        <source>External Mixer</source>
        <translation>Extern mengpaneel</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="55"/>
        <source>Launch mixer</source>
        <translation>Mengpaneel openen</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="56"/>
        <source>Mi&amp;xer</source>
        <translation>&amp;Mengpaneel</translation>
    </message>
</context>
</TS>
